City class abstract

Constructors

City()

Properties

accent_city → String
no setter
city → String
no setter
country → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
latitude → double
no setter
longitude → double
no setter
region → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

debug_string() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited